@@ -1,32 +1,38 @@
+from __future__ import absolute_import
 import sys
 import logging
 import logging.config
 import optparse
 
-from . import __version__
-from kuyruk import Kuyruk
-from config import Config
+from kuyruk import __version__
+from kuyruk.kuyruk import Kuyruk
+from kuyruk.config import Config
 
 logger = logging.getLogger(__name__)
 
 
 def main():
-    parser = optparse.OptionParser()
-    parser.add_option('--version', action='store_true')
-    parser.add_option('--config')
-    parser.add_option('--logging-config')
-    parser.add_option('--logging-level', default='INFO')
+    parser = optparse.OptionParser(version=__version__)
+    parser.add_option('-c', '--config')
+    log_levels = ['DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL']
+    parser.add_option(
+        '-l', '--logging-level', default='INFO',
+        choices=log_levels,
+        help="any of %s" % ', '.join(log_levels))
+    parser.add_option(
+        '--logging-config',
+        help="INI style logging configuration file")
+
     # These options below override the options from config module
-    parser.add_option('--queues')
+    parser.add_option(
+        '--queues',
+        help="comma seperated list of queues that the workers will run on")
     parser.add_option('--max-load', type='float')
     parser.add_option('--max-run-time', type='float')
     parser.add_option('--save-failed-tasks', action='store_true')
+    parser.add_option('--no-save-failed-tasks', action='store_true')
     options, args = parser.parse_args()
 
-    if options.version:
-        print __version__
-        sys.exit()
-
     if options.logging_config:
         logging.config.fileConfig(options.logging_config)
     else:
@@ -43,7 +49,9 @@ def main():
         config.MAX_RUN_TIME = options.max_run_time
 
     if options.save_failed_tasks:
-        config.SAVE_FAILED_TASKS = options.save_failed_tasks
+        config.SAVE_FAILED_TASKS = True
+    elif options.no_save_failed_tasks:
+        config.SAVE_FAILED_TASKS = False
 
     kuyruk = Kuyruk()
     kuyruk.config = config
