@@ -1,13 +1,16 @@
+from __future__ import absolute_import
+import os
 import json
 import socket
 import logging
+import traceback
 from functools import wraps
 from threading import RLock
 
 import pika
 import pika.exceptions
 
-from .message import Message
+from kuyruk.message import Message
 
 logger = logging.getLogger(__name__)
 
@@ -64,7 +67,7 @@ class Queue(object):
 
     @synchronized
     def declare(self):
-        logger.warning('Declaring queue: %s', self.name)
+        logger.info('Declaring queue: %s', self.name)
         return self.channel.queue_declare(
             queue=self.name, durable=True,
             exclusive=False, auto_delete=False)
@@ -117,10 +120,12 @@ class Queue(object):
 
     @synchronized
     def recover(self):
+        logger.debug('Recovering messages')
         return self.channel.basic_recover(requeue=True)
 
     @synchronized
     def delete(self):
+        logger.warning('Deleting queue')
         try:
             return self.channel.queue_delete(queue=self.name)
         except pika.exceptions.ChannelClosed as e:
@@ -130,8 +135,27 @@ class Queue(object):
 
     @synchronized
     def basic_consume(self, callback):
+        logger.debug('Issuing Basic.Consume')
         return self.channel.basic_consume(callback, self.name)
 
     @synchronized
     def basic_cancel(self, consumer_id):
+        logger.debug('Issuing Basic.Cancel')
         return self.channel.basic_cancel(consumer_id)
+
+    @synchronized
+    def process_data_events(self):
+        try:
+            self.channel.connection.process_data_events()
+        except Exception as e:
+            logger.debug(e)
+            if e.args[0] == 4:  # Interrupted system call
+                # Happens when a signal is received. No harm.
+                pass
+            else:
+                logger.critical(traceback.format_exc())
+                os._exit(1)
+
+    @synchronized
+    def sleep(self, seconds):
+        self.channel.connection.sleep(seconds)
