@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 import os
 import signal
 import logging
@@ -5,14 +6,14 @@ import traceback
 import threading
 import multiprocessing
 from time import sleep
-from functools import wraps
 
 from setproctitle import setproctitle
 
-from . import loader
-from .queue import Queue
-from .channel import LazyChannel
-from .consumer import Consumer
+from kuyruk import importer
+from kuyruk.queue import Queue
+from kuyruk.channel import LazyChannel
+from kuyruk.consumer import Consumer
+from kuyruk.helpers import start_daemon_thread
 
 logger = logging.getLogger(__name__)
 
@@ -33,7 +34,6 @@ class Worker(multiprocessing.Process):
         is_local = queue_name.startswith('@')
         self.queue = Queue(queue_name, self.channel, local=is_local)
         self.consumer = Consumer(self.queue)
-        self.processor = None
         self.shutdown_pending = threading.Event()
 
     def run(self):
@@ -49,44 +49,22 @@ class Worker(multiprocessing.Process):
         self.register_signals()
         self.queue.declare()
         self.channel.basic_qos(prefetch_count=1)
-        # self.channel.tx_select()
+        self.channel.tx_select()
 
-        # Start daemon threads
-        start_thread(self.watch_master, daemon=True)
-        start_thread(self.watch_load, daemon=True)
+        # Start threads
+        start_daemon_thread(self.watch_master)
+        start_daemon_thread(self.watch_load)
         if self.config.MAX_RUN_TIME > 0:
-            start_thread(self.count_run_time, daemon=True)
+            start_daemon_thread(self.shutdown_timer)
 
-        logger.info('Starting consume')
-        for message in self.consumer:
-            self.on_message(message)
-            # self.channel.tx_commit()
-
-        # Finish last task
-        if self.processor:
-            while self.processor.is_alive():
-                with self.queue.lock:
-                    self.channel.connection.process_data_events()
+        # Consume messages
+        with self.consumer.consume() as messages:
+            for message in messages:
+                self.process_task(message)
+                self.channel.tx_commit()
 
         logger.debug("End run worker")
 
-    def on_message(self, message):
-        """Start a new thread and run process task in it."""
-        logger.info('Message received: %s', message)
-        target = self.stop_consumer_on_exception(self.process_task)
-        self.processor = start_thread(target, (message, ))
-
-    def stop_consumer_on_exception(self, f):
-        @wraps(f)
-        def inner(*args, **kwargs):
-            try:
-                return f(*args, **kwargs)
-            except Exception:
-                logger.critical(traceback.format_exc())
-                logger.critical('Error in task processor, exiting')
-                os._exit(1)
-        return inner
-
     def process_task(self, message):
         from kuyruk import Kuyruk
 
@@ -140,7 +118,7 @@ class Worker(multiprocessing.Process):
             task_description['object_id'],
             task_description['args'],
             task_description['kwargs'])
-        task, cls = loader.import_task(module, cls, function,
+        task, cls = importer.import_task(module, cls, function,
                                        self.config.IMPORT_PATH)
 
         if cls:
@@ -166,7 +144,7 @@ class Worker(multiprocessing.Process):
             return False
 
     def watch_master(self):
-        """Watch the master and send itself SIGTERM when it is dead."""
+        """Watch the master and shutdown gracefully when it is dead."""
         while not self.shutdown_pending.is_set():
             if not self.is_master_alive():
                 logger.critical('Master is dead')
@@ -174,6 +152,7 @@ class Worker(multiprocessing.Process):
             sleep(1)
 
     def watch_load(self):
+        """Pause consuming messages if lood goes above the allowed limit."""
         while not self.shutdown_pending.is_set():
             load = os.getloadavg()[0]
             if load > self.config.MAX_LOAD:
@@ -181,9 +160,9 @@ class Worker(multiprocessing.Process):
                 self.consumer.pause(10)
             sleep(1)
 
-    def count_run_time(self):
-        """Counts down from MAX_RUN_TIME. When it reaches
-        zero it sends a signal to itself for graceful shutdown.
+    def shutdown_timer(self):
+        """Counts down from MAX_RUN_TIME. When it reaches zero sutdown
+        gracefully.
 
         """
         sleep(self.config.MAX_RUN_TIME)
@@ -208,13 +187,6 @@ class Worker(multiprocessing.Process):
         self.consumer.stop()
 
 
-def start_thread(target, args=(), daemon=False):
-    t = threading.Thread(target=target, args=args)
-    t.daemon = daemon
-    t.start()
-    return t
-
-
 def print_stack(sig, frame):
     print '=' * 70
     print ''.join(traceback.format_stack())
